# APACHE Module

## Overview

This module install and configure apache web server.

## Usage

Default configuration:

```puppet
include apache
```

Change configuration file settings:

```puppet
class { 'apache':
    servername      => 'www.nanonet.com',
    include         => [ 'Include sites-enabled/*.conf' ],
}
```

Create virtualhost:

```puppet
class { 'apache::virtualhost':
    filename        => 'example.com.conf',
    virtualhost     => {
        '*:80' => [
            'ServerAdmin admin@example.com',
            'DocumentRoot /var/www/example.com/public_html/',
            'ServerName example.com',
            'ServerAlias www.example.com',
            'ErrorLog /var/www/example.com/error.log',
            'CustomLog /var/www/example.com/access.log combined',
        ],
    },
}
```

Proxy customisation:

```puppet
class { 'apache':
    proxyrequests   => 'Off',
    proxypass       => '/ balancer://cluster lbmethod=byrequests',
    proxy           => {
        '*' => [
            'Order deny,allow',
            'Deny from none',
            'Allow from all',
        ],
        'balancer://cluster' => [
            'BalancerMember http://node1.example.com/ loadfactor=1',
            'BalancerMember http://node2.example.com/ loadfactor=1',
        ],
    },
}
```

Modsecurity customisation:

```puppet
class { 'apache::modsecurity':
    secruleengine           => 'On',
    secrequestbodyaccess    => 'On',
    secresponsebodyaccess   => 'On',
    secdatadir              => undef,
}
```

Other customisation:

```puppet
class { 'apache':
    serversignature => 'Off',
    servertokens    => 'Prod',
    fileetag        => 'None',
}
```
